import { MONTH_INDEX as N } from "./config/constants.js";
import { ArDateFormats as u } from "./types/enums.js";
const b = (f, t) => ("" + f).padStart(2, "0") + (t || ""), M = (f, t) => ("" + f).substring(2) + (t || ""), Y = (f, t, e) => {
  const r = N[f];
  return (t ? r.substring(0, 4) : r) + (e || "");
};
class y {
  /**
   * Calendar constructor
   *
   * @param  options  Calendar options
   */
  constructor({
    startDate: t = null,
    endDate: e = null,
    siblingMonths: r = !1,
    weekNumbers: n = !1,
    weekStart: a = 0
  } = {}) {
    this.startDate = t, this.endDate = e, this.siblingMonths = r, this.weekNumbers = n, this.weekStart = a;
  }
  /**
   * Calculate a calendar month
   *
   * @param   year   Year
   * @param   month  Month [0-11]
   * @return         Calendar days
   */
  getCalendar(t, e) {
    const r = new Date(Date.UTC(t, e, 1, 0, 0, 0, 0));
    t = r.getFullYear(), e = r.getMonth();
    const n = [], a = r.getDay(), s = -((7 - this.weekStart + a) % 7), m = y.daysInMonth(t, e), w = (m - s) % 7, T = y.daysInMonth(t, e - 1);
    let c = s, g, o, i = !1, D = null, l, h;
    const v = m - c + (w !== 0 ? 7 - w : 0) + s;
    for (; c < v; )
      o = c + 1, g = ((c < 1 ? 7 + c : c) + a) % 7, o < 1 || o > m ? this.siblingMonths ? (o < 1 ? (l = e - 1, h = t, l < 0 && (l = 11, h--), o = T + o) : o > m && (l = e + 1, h = t, l > 11 && (l = 0, h++), o = c - m + 1), l !== void 0 && h !== void 0 && (i = {
        day: o,
        weekDay: g,
        month: l,
        year: h,
        siblingMonth: !0
      })) : i = !1 : i = {
        day: o,
        weekDay: g,
        month: e,
        year: t
      }, i && this.weekNumbers && (D === null ? D = y.calculateWeekNumber(i) : g === 1 && D === 52 ? D = 1 : g === 1 && D++, i.weekNumber = D), i && this.startDate && (i.selected = this.isDateSelected(i)), n.push(i), c++;
    return n;
  }
  /**
   * Checks if a date is selected
   *
   * @param   date  Date object
   * @return        Selected status of the date
   */
  isDateSelected(t, e) {
    if (!this.startDate || e === null)
      return !1;
    let r = this.startDate;
    return e ? y.compare(this.startDate, e) === 1 && (r = e, e = this.startDate) : e = this.endDate, t.year === r.year && t.month === r.month && t.day === r.day ? !0 : !(!e || t.year === r.year && t.month === r.month && t.day < r.day || t.year === e.year && t.month === e.month && t.day > e.day || t.year === r.year && t.month < r.month || t.year === e.year && t.month > e.month || t.year < r.year || t.year > e.year);
  }
  /**
   * Sets the selected period start
   *
   * @param  date  Date object
   */
  setStartDate(t) {
    this.startDate = t;
  }
  /**
   * Sets the selected period end
   *
   * @param  date  Date object
   */
  setEndDate(t) {
    this.endDate = t;
  }
  /**
   * Sets one selected date
   *
   * @param  date  Date object
   */
  setDate(t) {
    return this.setStartDate(t);
  }
  /**
   * Calculates the difference between two dates (date1 - date2), in days
   *
   * @param   dateLeft   Date object
   * @param   dateRight  Date object
   * @return             Days between the dates
   */
  static diff(t, e) {
    const r = new Date(
      Date.UTC(t.year, t.month, t.day, 0, 0, 0, 0)
    ), n = new Date(
      Date.UTC(e.year, e.month, e.day, 0, 0, 0, 0)
    );
    return Math.ceil(
      (r.getTime() - n.getTime()) / 864e5
    );
  }
  /**
   * Calculates the interval between two dates
   *
   * @param   dateLeft   Date object
   * @param   dateRight  Date object
   * @return             Number of days between dates
   */
  static interval(t, e) {
    return Math.abs(y.diff(t, e)) + 1;
  }
  /**
   * Quickly compare two dates
   *
   * @param   dateLeft   Left `CalendarDate` object
   * @param   dateRight  Right `CalendarDate` object
   * @return             Comparison result: -1 (left < right), 0 (equal) or 1 (left > right)
   */
  static compare(t, e) {
    if (typeof t != "object" || typeof e != "object" || t === null || e === null)
      throw new TypeError("dates must be objects");
    return t.year < e.year ? -1 : t.year > e.year ? 1 : t.month < e.month ? -1 : t.month > e.month ? 1 : t.day < e.day ? -1 : t.day > e.day ? 1 : 0;
  }
  /**
   * Calculates the number of days in a month
   *
   * @param   year  Year
   * @param   month Month [0-11]
   * @return        Length of the month
   */
  static daysInMonth(t, e) {
    return new Date(t, e + 1, 0).getDate();
  }
  /**
   * Calculates if a given year is a leap year
   *
   * @param   year  Year
   * @return        Leap year or not
   */
  static isLeapYear(t) {
    return t % 4 === 0 && t % 100 !== 0 || t % 400 === 0;
  }
  /**
   * Calculates the week number for a given date
   *
   * @param   date  Date object
   * @return        Week number
   */
  // Adapted from http://techblog.procurios.nl/k/news/view/33796/14863/calculate-iso-8601-week-and-year-in-javascript.html
  static calculateWeekNumber(t) {
    const e = new Date(
      Date.UTC(t.year, t.month, t.day, 0, 0, 0, 0)
    ), r = new Date(e.valueOf()), n = (e.getUTCDay() + 6) % 7;
    r.setUTCDate(r.getUTCDate() - n + 3);
    const a = r.valueOf();
    return r.setUTCMonth(0, 1), r.getUTCDay() !== 4 && r.setUTCMonth(0, 1 + (4 - r.getUTCDay() + 7) % 7), 1 + Math.ceil((a - r.getTime()) / 6048e5);
  }
  static toString(t, e = "/", r = "DDMMYYYY") {
    const n = b(t.day, e), a = b(t.month + 1, e), s = t.year;
    switch (r) {
      case u.MMDDYY:
        return a + n + M(s);
      case u.DDMMYYYY:
        return n + a + s;
      case u.MMDDYYYY:
        return a + n + s;
      case u.DDMMMYY:
        return n + Y(t.month + 1, !0, e) + M(s);
      case u.DDMMMYYYY:
        return n + Y(t.month + 1, !0, e) + s;
      case u.MMMDDYY:
        return Y(t.month + 1, !0, e) + n + M(s);
      case u.MMMDDYYYY:
        return Y(t.month + 1, !0, e) + n + s;
      case u.YYMMDD:
        return M(s) + a + n;
      case u.YYMMMDD:
        return M(s) + Y(t.month + 1, !0, e) + n;
      case u.YYYYMMDD:
        return s + a + n;
      case u.YYYYMMMDD:
        return s + Y(t.month + 1, !0, e) + n;
      case u.DDMMYY:
      default:
        return n + a + M(s);
    }
  }
  static getPreviousMonth(t) {
    const e = t.getMonth(), r = t.getFullYear(), n = e === 0 ? 11 : e - 1, a = e === 0 ? r - 1 : r, s = /* @__PURE__ */ new Date();
    return s.setDate(t.getDate()), s.setMonth(n), s.setFullYear(a), s;
  }
  static getNextMonth(t) {
    const e = t.getMonth(), r = t.getFullYear(), n = e === 11 ? 0 : e + 1, a = e === 11 ? r + 1 : r, s = /* @__PURE__ */ new Date();
    return s.setDate(t.getDate()), s.setMonth(n), s.setFullYear(a), s;
  }
  static getPreviousYear(t) {
    const e = t.getFullYear(), r = /* @__PURE__ */ new Date();
    return r.setDate(t.getDate()), r.setMonth(t.getMonth()), r.setFullYear(e === 1 ? 1 : e - 1), r;
  }
  static getNextYear(t) {
    const e = t.getFullYear(), r = /* @__PURE__ */ new Date();
    return r.setDate(t.getDate()), r.setMonth(t.getMonth()), r.setFullYear(e + 1), r;
  }
}
export {
  y as default,
  b as pad,
  M as sub
};
