import { Moment } from "moment";
import { ChangeEvent, HTMLInputTypeAttribute, MouseEventHandler, ReactNode, InputHTMLAttributes, FocusEvent, CSSProperties } from "react";
import { ArAccordionStyles, ArAccordionVariants, ArAlertType, ArAnimations, ArBadgeType, ArButtonTypes, ArButtonVariants, ArCalViews, ArIconTileTypes, ArLoaderTypes, ArMonthSelectorViews, ArPageTriggers, ArPillSizes, ArPlacement, ArPopoverPositions, ArPopoverTriggers, ArSizes, ArVisualizationTypes } from "./enums";
import { AppNavigatorDataType, BreadCrumbData, CalendarDate, Config, Event, FrameContentDefinition, Locale, Namespace, OptionType, PageInfoType, PresetDefinition, SearchItem, Task, ToolItemConfig, TreeListData } from "./entity.interface";
import { User } from "./entity.interface";
import { IconResponse, PageItem } from "./iconresponse.interface";
import { AnimationHandler, ArrayType, CheckBoxTypes, DateFormat, FunctionType, ObjectType, StopSwipingHandler, SwipeAnimationHandler } from "./types";
import { CalendarInstance } from "../helper";
export interface BaseProps {
    classes?: string;
    containerClasses?: string;
    childClasses?: string;
    demo?: boolean;
    slot?: string;
    style?: CSSProperties;
    theme?: string;
}
export interface FormInputProps extends BaseProps {
    ariaLabel?: string;
    assistiveContent?: JSX.Element | {
        content: string;
        onClick: MouseEventHandler<HTMLButtonElement>;
    };
    id?: string;
    name?: string;
    value?: string | number | boolean | ObjectType;
    label?: string;
    labelClasses?: string;
    labelPlacement?: ArPlacement;
    onBlur?: (event: ChangeEvent<unknown>) => void | FunctionType;
    onChange?: (event: ChangeEvent<unknown>) => void | FunctionType;
    onFocus?: (event: FocusEvent<unknown>) => void | FunctionType;
    size?: ArSizes;
}
export interface DateRangePickerProps extends FormInputProps {
    closeOnEndSelect?: boolean;
}
export interface LottieTileProps extends BaseProps {
    preset: PresetDefinition;
    setSelectedPresets: FunctionType;
}
export interface AssetSelectorProps extends BaseProps {
}
export interface AccordionProps extends BaseProps {
    data: Array<AccordionExpansionPanelProps>;
    firstExpanded?: boolean;
    variant?: ArAccordionVariants;
    appearance?: ArAccordionStyles;
    isRemovable?: boolean;
}
export interface AccordionExpansionPanelProps extends BaseProps {
    id: string;
    title: string;
    expanded?: boolean;
    isRemovable?: boolean;
    setExpandedId?: FunctionType;
    content: ReactNode;
}
export interface LottieLayersProps extends BaseProps {
}
export interface LottieEditorToolsProps extends BaseProps {
    setSelectedPresets: FunctionType;
}
export interface LottieEditorProps extends BaseProps {
    selectedPresets?: Array<PresetDefinition>;
}
export interface IconMergeContainerProps extends BaseProps {
    icons: Array<IconResponse>;
}
export interface AdvancedColorPickerProps extends BaseProps {
    displaySample?: boolean;
    id?: string;
    onColorSelect?: (arg: string) => void;
    title?: string;
}
export interface IconEditorProps extends BaseProps {
    layout?: string;
}
export interface IconStyleSelectorProps extends BaseProps {
    iconStyles?: {
        fillColor?: string;
        strokeColor?: string;
        bgColor?: string;
        strokeWidth?: string;
    };
    layout?: string;
    setIconStyles: FunctionType;
}
export interface TilesProps extends BaseProps {
    data: AppNavigatorDataType;
}
export interface PlaygroundTileProps extends BaseProps {
}
export interface ProductDescriptionTileProps extends BaseProps {
    name: string;
    description: Array<string>;
    image: string;
    imagePlacement?: ArPlacement;
    onClick?: FunctionType;
}
export interface LandingContentProps extends BaseProps {
}
export interface FlexToolsProps extends BaseProps {
    isLanding?: boolean;
    route?: string;
}
export interface AppAndToolsSelectorProps extends BaseProps {
    data: Array<AppNavigatorDataType>;
}
export interface AppTileProps extends BaseProps {
    label: string;
    icon: string;
    url?: string;
    onClick?: FunctionType;
    description?: Array<string>;
}
export interface FontTileProps extends BaseProps {
    font: string;
}
export interface FontsListProps extends BaseProps {
}
export interface BubbleChartProps extends BaseProps {
    clickHandler?: FunctionType;
    data: Array<ObjectType>;
}
export interface CronTabProps extends BaseProps {
    onChange: FunctionType;
    value?: ObjectType | string;
}
export interface CarouselProps extends BaseProps {
    ariaLabel?: string | undefined;
    axis: "horizontal" | "vertical";
    autoFocus?: boolean;
    autoPlay?: boolean;
    centerMode?: boolean;
    centerSlidePercentage: number;
    children?: ReactNode;
    className?: string;
    dynamicHeight?: boolean;
    emulateTouch?: boolean;
    infiniteLoop?: boolean;
    interval: number;
    labels: {
        leftArrow: string;
        rightArrow: string;
        item: string;
    };
    noMarkers?: boolean;
    onClickItem: (index: number, item: React.ReactNode) => void;
    onClickThumb: (index: number, item: React.ReactNode) => void;
    onChange: (index: number, item: React.ReactNode) => void;
    onSwipeStart: (event: React.TouchEvent) => void;
    onSwipeEnd: (event: React.TouchEvent) => void;
    onSwipeMove: (event: React.TouchEvent) => boolean;
    preventMovementUntilSwipeScrollTolerance: boolean;
    renderArrowPrev: (clickHandler: () => void, hasPrev: boolean, label: string) => React.ReactNode;
    renderArrowNext: (clickHandler: () => void, hasNext: boolean, label: string) => React.ReactNode;
    renderIndicator: (clickHandler: (e: React.MouseEvent | React.KeyboardEvent) => void, isSelected: boolean, index: number, label: string) => React.ReactNode;
    renderItem: (item: React.ReactNode, options?: {
        isSelected: boolean;
        isPrevious: boolean;
    }) => React.ReactNode;
    renderThumbs: (children: ReactNode) => ReactNode;
    selectedItem: number;
    showArrows: boolean;
    showStatus: boolean;
    showIndicators: boolean;
    showThumbs: boolean;
    statusFormatter: (currentItem: number, total: number) => string;
    stopOnHover: boolean;
    swipeable: boolean;
    swipeScrollTolerance: number;
    thumbWidth?: number;
    transitionTime: number;
    useKeyboardArrows?: boolean;
    verticalSwipe: "natural" | "standard";
    width: number | string;
    animationHandler: "slide" | "fade" | AnimationHandler;
    swipeAnimationHandler: SwipeAnimationHandler;
    stopSwipingHandler: StopSwipingHandler;
}
export interface SwiperProps extends BaseProps {
    tagName?: string;
    className: string;
    style: CSSProperties;
    children?: ReactNode;
    allowMouseEvents?: boolean;
    onMouseDown?: FunctionType;
    onSwipeUp?: FunctionType;
    onSwipeDown?: FunctionType;
    onSwipeLeft?: FunctionType;
    onSwipeRight?: FunctionType;
    onSwipeStart?: FunctionType;
    onSwipeMove?: FunctionType;
    onSwipeEnd?: FunctionType;
    onTouchStart?: FunctionType;
    onTouchEnd?: FunctionType;
    innerRef?: FunctionType;
    tolerance: number;
}
export interface TaskFormProps extends BaseProps {
}
export interface TaskListProps extends BaseProps {
    list?: Array<Task>;
    taskFetcher: FunctionType;
}
export interface TaskLoginPromptProps extends BaseProps {
}
export interface TaskViewerProps extends BaseProps {
    hideSelf: FunctionType;
    isNew?: boolean;
    selectedTask?: Task;
    taskFetcher: FunctionType;
}
export interface NamespaceInfoBoxProps extends BaseProps {
    namespace: Namespace;
}
export interface ConfigRowItemProps extends BaseProps {
    config?: Config;
    disabled?: boolean;
    isNew?: boolean;
    onAdd?: (key: string, value: string) => void;
    onUpdate?: (_id: string, key: string, value: string) => void;
    onDelete?: (_id?: string) => void;
}
export interface NamespaceFormProps extends BaseProps {
    context: string;
}
export interface ConfigurationLoginPromptProps extends BaseProps {
}
export interface ConfigurationNoConfigPromptProps extends BaseProps {
}
export interface ConfigurationViewerProps extends BaseProps {
    namespace: Namespace;
    fetchNamespaces: () => void;
}
export interface ConfigurationListProps extends BaseProps {
    list?: Array<TreeListData>;
}
export interface SegmentedControlProps extends FormInputProps {
    segments: Array<{
        isIcon?: boolean;
        icon?: string;
        label?: string;
        name?: string;
        tooltip?: string;
    }>;
}
export interface BubbleVizProps extends BaseProps {
    data: ArrayType | ObjectType;
}
export interface ArVizProps extends BaseProps {
    clickHandler?: FunctionType;
    type: ArVisualizationTypes;
    data: ArrayType | ObjectType;
}
export interface SuggestionsProps extends BaseProps {
    inSvgString?: boolean;
    suggestions?: Array<ObjectType | string>;
    title?: string;
}
export interface SuggestionProps extends BaseProps {
    suggestion?: ObjectType | string;
    inSvgString?: boolean;
}
export interface IconControllerProps extends BaseProps {
    group?: string;
    name?: string;
    icon?: ObjectType;
}
export interface TagsProps extends BaseProps {
    clickHandler?: FunctionType;
    hideHeader?: boolean;
    label?: string;
    tags?: ObjectType;
}
export interface ColorSelectorProps extends BaseProps {
    label?: string;
    onChange?: FunctionType;
    withSample?: boolean;
}
export interface LoginProviderProps extends BaseProps {
    url?: string;
}
export interface UserOptionsProps extends BaseProps {
    isLanding?: boolean;
    options: Array<{
        name: string;
    }> | Array<Array<{
        name: string;
    }>>;
}
export interface FavoritesListProps extends BaseProps {
}
export interface FavoritesItemProps extends BaseProps {
    index: string | number;
    favorite: IconTileProps;
}
export interface SidePanelProps extends BaseProps {
    hideCloseButton?: boolean;
    isFloating?: boolean;
    componentName?: string;
    componentProps?: ObjectType;
    header?: ReactNode;
    placement?: ArPlacement;
}
export interface LoaderProps extends BaseProps {
    type?: ArLoaderTypes;
    size?: ArSizes;
    label?: string;
    icon?: string;
    progress?: number;
}
export interface LoadableIconProps extends BaseProps {
    color?: string;
    icon?: string;
    skipPathColorFill?: boolean;
    svgString?: string;
    svgB64String?: string;
    height?: string;
    hoverColor?: string;
    hoverShadow?: boolean;
    isLocal?: boolean;
    onClick?: MouseEventHandler<HTMLImageElement>;
    onMouseEnter?: MouseEventHandler<HTMLImageElement>;
    onMouseLeave?: MouseEventHandler<HTMLImageElement>;
    size?: string;
    toggleColor?: string;
    toggled?: boolean;
    width?: string;
    fillColor?: string;
    strokeColor?: string;
    strokeWidth?: string;
}
export interface IconProps extends BaseProps {
    alt?: string;
    color?: string;
    height?: string;
    onClick?: MouseEventHandler;
    onMouseEnter?: MouseEventHandler;
    onMouseLeave?: MouseEventHandler;
    size?: string;
    src: string;
    width?: string;
}
export interface TabProps extends BaseProps {
    bubbleDimensions?: Function;
    data?: any;
    items?: Array<TabProps>;
    deletable?: boolean;
    icon?: string;
    id?: string;
    isActive?: boolean;
    label: string;
    onHover?: FunctionType;
    onHoverOut?: FunctionType;
    onSelect?: FunctionType;
    size?: string;
    variant?: string;
}
export interface TabBarProps extends BaseProps {
    activeId?: string;
    data: Array<TabProps>;
    onTabSelected?: (id: string, data: any) => void;
    size?: string;
    variant?: string;
    [key: string]: any;
}
export interface AlertProps extends BaseProps {
    closeable?: boolean;
    position?: string;
    show?: boolean;
    type?: ArAlertType;
    message: string;
    timeout?: number;
    uid: string;
}
export interface BrowserIncompatibilityProps extends BaseProps {
    applicationName?: string;
    moreLink?: string;
}
interface LinkBaseProps extends BaseProps {
    to: string;
    onClick?: MouseEventHandler;
    openInNew?: boolean;
    preemptNavigation?: boolean;
}
interface LinkLabelProps extends LinkBaseProps {
    label: string;
}
interface LinkChildrenProps extends LinkBaseProps {
    children: ReactNode;
}
export type LinkProps = (LinkLabelProps & Partial<LinkChildrenProps>) | (Partial<LinkLabelProps> & LinkChildrenProps);
export interface Component_404Props extends BaseProps {
    iconSize?: string;
}
export interface FrameContentProps extends BaseProps {
    contentDefinition: FrameContentDefinition | null;
    notificationProps?: any;
}
export interface TreeListProps extends BaseProps {
    data: Array<TreeListData>;
    firstExpanded?: boolean;
    indentation?: string;
    noSearch?: boolean;
    title?: string;
    onItemSelect?: Function;
    withAddButton?: boolean;
}
export interface TreeListItemProps extends BaseProps {
    hierarchyLevel: number;
    data: TreeListData;
    indentation?: number;
    onItemSelect?: Function;
    setSelected?: Function;
    selected?: string;
    isAddButton?: boolean;
    indentationUnit?: string;
}
interface BaseSearchProps extends BaseProps {
    categories?: Array<OptionType>;
    data: Array<SearchItem>;
    placeholder?: string;
    searchFor?: string | Array<string>;
}
interface SearchPropsWithOnClick extends BaseSearchProps {
    onChange: (event: ChangeEvent<HTMLInputElement>, filteredItems: Array<SearchItem> | null) => void;
}
interface SearchPropsWithPopperPrevented extends BaseSearchProps {
    showPopUp: boolean;
}
export type SearchProps = SearchPropsWithOnClick | SearchPropsWithPopperPrevented;
export interface InputProps extends FormInputProps {
    label?: string;
    placeholder?: string;
    type?: HTMLInputTypeAttribute;
    value?: string | number;
}
export type TextInputProps = InputHTMLAttributes<HTMLInputElement> & Omit<InputProps, "onChange">;
export type SliderProps = {
    focussed?: boolean;
    withManual?: boolean;
} & TextInputProps;
export interface IconsListProps extends BaseProps {
    icons?: Array<IconResponse>;
    variant?: string;
}
export interface IconTileProps extends BaseProps {
    hideBorder?: boolean;
    hideFooter?: boolean;
    icon: IconResponse;
    iconSize?: string;
    onClick?: Function;
    selectable?: boolean;
    tools?: Array<ToolItemConfig>;
    toolsPlacement?: string;
    type?: ArIconTileTypes;
    fillColor?: string;
    strokeColor?: string;
    strokeWidth?: string;
}
export interface ButtonProps extends BaseProps {
    content: string | JSX.Element | undefined;
    color?: string;
    disabled?: boolean;
    preIcon?: string;
    postIcon?: string;
    onClick?: MouseEventHandler<HTMLButtonElement>;
    size?: string;
    type?: ArButtonTypes;
    variant?: ArButtonVariants;
    splitOptions?: Array<ListItemProps>;
    splitTrigger?: ArPopoverTriggers;
}
export interface DrawerProps {
    children?: ReactNode;
    classes?: string;
    isCollapsible?: boolean;
    collapsed?: boolean;
}
export interface PaginationProps extends BaseProps {
    count: number;
    isHeadless?: boolean;
    load: number;
    trigger?: ArPageTriggers;
    maxPillsToShow?: number;
    pageSetter?: FunctionType;
    pageSize?: number;
    data?: Array<PageItem>;
    dataFetcher?: FunctionType;
}
export interface HeaderProps {
    routeDetails?: ObjectType;
    user?: User;
    onLogin?: () => void;
    onLogout?: () => void;
    onCreateAccount?: () => void;
}
export interface PopoverProps extends BaseProps {
    animation?: ArAnimations;
    children: Array<JSX.Element | null>;
    contentClasses?: string;
    isOpen?: boolean;
    position?: ArPopoverPositions;
    transition?: boolean;
    trigger?: ArPopoverTriggers;
}
export interface InlineMenuProps extends BaseProps {
    data: {
        [key: string]: any;
    };
    top?: number;
    left?: number;
}
export interface ContextMenuProps extends BaseProps {
    children?: string | JSX.Element | Array<JSX.Element>;
    data: {
        [key: string]: any;
    };
}
export interface ListItemContent {
    label?: string;
    name?: string;
    onClick?: FunctionType;
}
export type ListItemProps = string | ListItemContent | Array<ListItemProps>;
export interface ListProps extends BaseProps {
    data: Array<ListItemProps>;
    itemClasses?: string;
}
export interface MainProps {
    contentClasses?: string;
    drawerContent?: ReactNode | false;
    mainContent?: ReactNode | false;
    hideSidepanelCloseButton?: boolean;
    rightPanelContent?: {
        name: string;
        props?: ObjectType;
    } | false;
    leftPanelContent?: {
        name: string;
        props?: ObjectType;
    } | false;
    rightPanelHeader?: ReactNode;
    leftPanelHeader?: ReactNode;
}
export interface DropdownProps extends FormInputProps {
    context?: string;
    id?: string;
    label?: string;
    onSelectionChanged: Function;
    options?: Array<OptionType>;
}
export interface ModalProps {
    body?: ReactNode;
    closeHandler?: FunctionType;
    content?: ReactNode;
    footer?: ReactNode;
    header?: ReactNode;
    isSticky?: boolean;
    primaryHandler?: FunctionType;
    show?: boolean;
}
export interface BreadcrumbProps extends BaseProps {
    data: Array<BreadCrumbData>;
    separator?: string;
    size?: ArSizes;
    onClick?: Function;
}
export interface BadgeProps extends BaseProps {
    icon?: string;
    size?: ArSizes;
    shadow?: boolean;
    text?: string;
    type?: ArBadgeType;
}
export interface TextAreaProps extends FormInputProps {
    placeholder?: string;
}
export interface DatePickerProps extends FormInputProps {
    allowEventSetting?: boolean;
    placeholder?: string;
}
export interface DateInputProps extends FormInputProps {
    placeholder?: string;
}
export interface DateRangeProps extends FormInputProps {
    alwaysShowCalendars?: boolean;
    applyButtonClasses?: string | Array<string>;
    applyClass?: string | Array<string>;
    autoApply?: boolean;
    autoUpdateInput?: boolean;
    buttonClasses?: string;
    callback?: FunctionType;
    cancelButtonClasses?: string | Array<string>;
    cancelClass?: string | Array<string>;
    dateLimit?: ObjectType;
    drops?: string;
    element?: JSX.Element;
    endDate?: string | Moment;
    isCustomDate?: FunctionType;
    isInvalidDate?: FunctionType;
    isShowing?: boolean;
    leftCalendar?: ObjectType;
    locale?: Locale;
    linkedCalendars?: boolean;
    maxDate?: boolean | Moment;
    maxSpan?: ObjectType;
    maxYear?: string;
    minDate?: boolean | Moment;
    minYear?: string;
    opens?: string;
    parentEl?: string;
    ranges?: {
        [key: string]: Array<Moment>;
    };
    rightCalendar?: ObjectType;
    singleDatePicker?: boolean;
    showDropdowns?: boolean;
    showWeekNumbers?: boolean;
    showISOWeekNumbers?: boolean;
    showCustomRangeLabel?: boolean;
    startDate?: string | Moment;
    timePicker?: boolean;
    timePicker24Hour?: boolean;
    timePickerSeconds?: boolean;
    timePickerIncrement?: number;
    updateElement?: FunctionType;
    updateMonthsInView?: FunctionType;
}
export interface DateProps extends FormInputProps {
    isRangeSelector?: boolean;
    minDate?: Date;
    maxDate?: Date;
    startDate?: Date;
    endDate?: Date;
    showTimePicker?: boolean;
    timePickerSeconds?: boolean;
    is12HourFormat?: boolean;
    showQuickSelectors?: boolean;
    customSelectors?: Array<ListItemProps>;
    showTodayInFooter?: boolean;
    showDropdowns?: boolean;
}
export interface CardProps extends BaseProps {
}
export interface SelectionPillProps extends BaseProps {
    context?: string;
    data: PageInfoType;
    disabled?: boolean;
    onClick: Function;
    selected?: boolean;
    size?: ArPillSizes;
}
export interface ToggleProps extends FormInputProps {
    id?: string;
    label?: string;
    toggleOnName?: string;
    toggleOffName?: string;
    isOn?: boolean;
    onChange: FunctionType;
}
export interface HeroProps extends BaseProps {
}
export interface CalendarProps extends BaseProps {
    allowEventSetting?: boolean;
    events?: Array<Event>;
    customDayEventSetter?: FunctionType;
    endDate?: Date | DateFormat | CalendarDate;
    hasTimeControls?: boolean;
    isSingleSelect?: boolean;
    maxDate?: Date | DateFormat | CalendarDate;
    minDate?: Date | DateFormat | CalendarDate;
    miniMode?: boolean;
    onDateSelected?: FunctionType;
    startDate?: Date | DateFormat | CalendarDate;
}
export interface MonthNavigatorProps extends BaseProps {
    currentDecade?: number;
    currentMonthNavView?: ArMonthSelectorViews | null;
    currentView: ArCalViews;
    currentYear?: number;
    miniMode?: boolean;
    refDate: Date;
    setCurrentDecade: FunctionType;
    setCurrentMonthNavView: FunctionType;
    setCurrentView: FunctionType;
    setCurrentYear: FunctionType;
    setRefDate: FunctionType;
}
export interface MonthSelectorProps extends BaseProps {
    currentDecade?: number;
    currentMonthNavView?: ArMonthSelectorViews | null;
    currentView: ArCalViews;
    currentYear?: number;
    miniMode?: boolean;
    onMonthSelect: FunctionType;
    setCurrentDecade: FunctionType;
    setCurrentMonthNavView: FunctionType;
    setCurrentView: FunctionType;
    setCurrentYear: FunctionType;
}
export interface JustCalendarProps extends BaseProps {
    allowEventSetting?: boolean;
    calHelper?: CalendarInstance;
    calendar?: Array<CalendarDate | false>;
    endDate?: CalendarDate;
    hovered?: CalendarDate;
    isSingleSelect?: boolean;
    miniMode?: boolean;
    onDateSelected: FunctionType;
    setHovered: FunctionType;
    startDate?: CalendarDate;
}
export interface EventFormProps extends BaseProps {
    events?: Array<Event>;
    miniMode?: boolean;
    selectedDate: CalendarDate;
}
export interface CheckboxProps extends FormInputProps {
    id?: string;
    label?: string;
    type?: CheckBoxTypes;
    onChange: FunctionType;
}
export interface ColorPickerProps extends BaseProps {
    id?: string;
    label?: string;
    onChange?: Function;
    value?: string;
}
export interface PasswordProps extends BaseProps {
    onChange: (event: ChangeEvent) => void;
}
export interface PillProps extends BaseProps {
    label: string | JSX.Element;
    data?: any;
    deletable?: boolean;
    onClick?: Function;
    onDelete?: Function;
}
export interface PillboxProps extends BaseProps {
    classes?: string;
    data: Array<PillProps>;
    onChange: Function;
}
export interface DetailsPanelProps extends BaseProps {
}
export interface DialogProps extends BaseProps {
}
export interface FacetedFilterProps extends BaseProps {
}
export interface LabelValueProps extends BaseProps {
}
export interface LearnLinkProps extends BaseProps {
}
export interface MaskProps extends BaseProps {
}
export interface NotificationProps extends BaseProps {
}
export interface NumericStepperProps extends BaseProps {
}
export interface PickerRangeProps extends BaseProps {
}
export interface PicklistProps extends BaseProps {
}
export interface ProgressIndicatorProps extends BaseProps {
    progress?: number;
}
export interface ProgressStepperProps extends BaseProps {
}
export interface RadioProps extends FormInputProps {
}
export interface SearchFieldProps extends BaseProps {
}
export interface SecondaryNavigationProps extends BaseProps {
}
export interface SelectProps extends FormInputProps {
}
export interface SplitterProps extends BaseProps {
}
export interface TableProps extends BaseProps {
}
export interface TagProps extends BaseProps {
}
export interface TimeEntryProps extends BaseProps {
}
export interface ToolbarProps extends BaseProps {
}
export interface TooltipProps extends BaseProps {
}
export interface TypeAheadProps extends BaseProps {
}
export interface UploaderProps extends BaseProps {
}
export interface WidgetProps extends BaseProps {
}
export interface AboutUsProps extends BaseProps {
}
export interface AlertStackManagerProps extends BaseProps {
}
export interface AlphabetFilterProps extends BaseProps {
}
export interface ApplicationProps extends BaseProps {
}
export interface BannerProps extends BaseProps {
}
export interface BenefitsProps extends BaseProps {
}
export interface BlogProps extends BaseProps {
}
export interface BrandsProps extends BaseProps {
}
export interface BreadcrumbsProps extends BaseProps {
}
export interface CareersProps extends BaseProps {
}
export interface CategoryFilterProps extends BaseProps {
}
export interface ContactProps extends BaseProps {
}
export interface ContentProps extends BaseProps {
}
export interface CookiesProps extends BaseProps {
}
export interface CtaProps extends BaseProps {
}
export interface DashboardProps extends BaseProps {
}
export interface DownloadProps extends BaseProps {
}
export interface EcommOrdersProps extends BaseProps {
}
export interface EcommProductsProps extends BaseProps {
}
export interface EmptyProps extends BaseProps {
}
export interface ErrorBoundaryProps extends BaseProps {
}
export interface FaqProps extends BaseProps {
}
export interface FeaturesProps extends BaseProps {
}
export interface FiltersProps extends BaseProps {
}
export interface FooterProps extends BaseProps {
}
export interface FormProps extends BaseProps {
}
export interface GalleryProps extends BaseProps {
}
export interface GraphProps extends BaseProps {
}
export interface GraphTilesProps extends BaseProps {
}
export interface HowItWorksProps extends BaseProps {
}
export interface HttpCodeProps extends BaseProps {
}
export interface InstaPhotosProps extends BaseProps {
}
export interface IntegrationsProps extends BaseProps {
}
export interface LogoCloudsProps extends BaseProps {
}
export interface NewsletterProps extends BaseProps {
}
export interface NotificationsProps extends BaseProps {
}
export interface PortfolioProps extends BaseProps {
}
export interface PricingProps extends BaseProps {
}
export interface ProductInfoProps extends BaseProps {
}
export interface ProjectsProps extends BaseProps {
}
export interface ReviewsProps extends BaseProps {
}
export interface RichTextProps extends BaseProps {
}
export interface ServicesProps extends BaseProps {
}
export interface SignInUpProps extends BaseProps {
}
export interface SnackbarProps extends BaseProps {
}
export interface StatsProps extends BaseProps {
}
export interface StepsProps extends BaseProps {
}
export interface TeamProps extends BaseProps {
}
export interface TestimonialsProps extends BaseProps {
}
export interface ToastProps extends BaseProps {
}
export interface UsersProps extends BaseProps {
}
export {};
