import { MouseEventHandler } from "react";
import { AppTileProps, BadgeProps, LoadableIconProps } from "./components.interface";
import { ArrayType, FunctionType, NSStates, ObjectType, SCOPES, STATES } from "./types";
import { ArAnimationInjectionTypes, ArAnimationProperty, ArEventStates, ArSchedules, JobStatus } from "./enums";
import { Animation, OffsetKeyframe } from "./lottie";
export interface FrameContentDefinition {
    componentName: string;
    component: JSX.ElementType;
    props?: {
        theme?: string;
        [key: string]: string | number | boolean | {
            [key: string]: any;
        } | undefined;
    };
    data: {
        [key: string]: any;
    };
    hierarchy: string;
}
export interface TreeListData {
    id?: string;
    badges?: Array<BadgeProps>;
    children?: Array<TreeListData>;
    data?: any;
    expanded?: boolean;
    label: string | boolean;
    onItemSelect?: Function;
    skipParentSelector?: boolean;
}
export interface AccordionData {
}
export interface ToolItemConfig {
    children?: Array<ToolItemConfig>;
    iconProps: LoadableIconProps;
    onClick: MouseEventHandler<HTMLImageElement>;
    name: string;
    tooltip?: string;
}
export interface User {
    name: string;
    email: string;
    username: string;
    password: string;
    role: string;
    createdAt: string;
    updatedAt: string;
}
export interface ComponentImport {
    [key: string]: () => Promise<{
        default: React.ComponentType<any>;
    }>;
}
export interface Config {
    _id: string;
    key: string;
    value: string;
    version: string;
}
export interface Org {
    _id?: string;
    name: string;
    state?: STATES;
    description?: string;
    email?: string;
    members?: Array<User>;
    owner?: User;
    logo?: string;
}
export interface Namespace {
    _id?: string;
    name: string;
    org: Org;
    state?: NSStates;
    configs?: Array<Config>;
    scope?: SCOPES;
    version: string;
}
export interface Task extends ObjectType {
    _id?: string;
    owner: string;
    schedule: {
        cron: string;
        starts?: Date;
        ends?: Date;
    };
    target: {
        endpoint: string;
        payload?: ObjectType;
    };
    name: string;
    description?: string;
    status: JobStatus;
}
export interface Locale {
    direction: string;
    format: string;
    separator: string;
    applyLabel: string;
    cancelLabel: string;
    weekLabel: string;
    customRangeLabel: string;
    daysOfWeek: Array<string>;
    monthNames: Array<string>;
    firstDay: number;
}
export interface AnimationHandlerResponse {
    itemListStyle?: React.CSSProperties;
    slideStyle?: React.CSSProperties;
    selectedStyle?: React.CSSProperties;
    prevStyle?: React.CSSProperties;
}
export interface CronType {
    min: string;
    hour: string;
    day: string;
    week: string;
    month: string;
}
export interface OptionType {
    label: string | JSX.Element;
    name?: string;
    value?: string | number;
    data?: object;
}
export interface PageInfoType extends OptionType {
    sliceIndex?: number;
    startIndex?: number;
    endIndex?: number;
}
export interface AppNavigatorDataType {
    label: string;
    items: Array<AppTileProps>;
    icon?: string;
    color?: string;
    url?: string;
    id?: string;
    active?: boolean;
}
export interface SearchItem {
    data?: object;
    label: string;
    children?: ArrayType;
}
export interface HOSTS {
    development: string;
    production: string;
}
export interface IconStyles {
    fillColor?: string;
    strokeColor?: string;
    bgColor?: string;
    strokeWidth?: string;
}
export interface RecursionArgs {
    data: any;
    op?: FunctionType;
    isBrute?: boolean;
    condition?: ObjectType;
    iterateOn?: string;
}
export interface PresetDefinition {
    name: string;
    from?: string;
    to?: string;
    property?: ArAnimationProperty;
    lottie?: Animation;
    raw?: Array<OffsetKeyframe>;
}
export interface AnimationInjectConfig {
    base?: Animation;
    type?: ArAnimationInjectionTypes;
    property: ArAnimationProperty;
    imageLink?: string;
    juice: Array<OffsetKeyframe>;
}
export interface CalendarDate {
    day: number;
    month: number;
    selected?: boolean;
    siblingMonth?: boolean;
    weekDay?: number;
    weekNumber?: number;
    year: number;
}
export interface Event {
    title: string;
    description?: string;
    state: ArEventStates;
    schedule?: Schedule;
}
export interface Schedule {
    starts: Date | ArSchedules;
    ends: Date | ArSchedules;
}
interface BaseBreadCrumbData {
    label: string;
    data?: any;
}
interface BreadcrumbDataWithClick extends BaseBreadCrumbData {
    onClick: Function;
}
interface BreadcrumbDataWithRoute extends BaseBreadCrumbData {
    route: string;
}
export type BreadCrumbData = BreadcrumbDataWithClick | BreadcrumbDataWithRoute;
export {};
